package com.rjconsultores.ventaboletos.web.gui.controladores.configuracioneccomerciales;

import java.util.HashMap;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.context.annotation.Scope;
import org.springframework.stereotype.Controller;
import org.zkoss.util.resource.Labels;
import org.zkoss.zhtml.Messagebox;
import org.zkoss.zk.ui.Component;
import org.zkoss.zk.ui.event.Event;
import org.zkoss.zk.ui.event.EventListener;
import org.zkoss.zul.Paging;
import org.zkoss.zul.Textbox;

import com.rjconsultores.ventaboletos.entidad.GrupoContrato;
import com.rjconsultores.ventaboletos.web.utilerias.MyGenericForwardComposer;
import com.rjconsultores.ventaboletos.web.utilerias.MyListbox;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.HibernateSearchObject;
import com.rjconsultores.ventaboletos.web.utilerias.paginacion.PagedListWrapper;
import com.rjconsultores.ventaboletos.web.utilerias.render.RenderPadrao;

@Controller("busquedaGrupoContratoController")
@Scope("prototype")
public class BusquedaGrupoContratoController extends MyGenericForwardComposer {

	private static final long serialVersionUID = 1L;
	@Autowired
	private transient PagedListWrapper<GrupoContrato> plwpagingGrupoContrato;
	private MyListbox grupoContratoList;
	private Paging pagingGrupoContrato;
	private Textbox txtDescricao;

	@Override
	public void doAfterCompose(Component comp) throws Exception {
		super.doAfterCompose(comp);

		grupoContratoList.setItemRenderer(new RenderPadrao<GrupoContrato>(GrupoContrato.class));
		grupoContratoList.addEventListener("onDoubleClick", new EventListener() {

			@Override
			public void onEvent(Event event) throws Exception {
				GrupoContrato cc = (GrupoContrato) grupoContratoList.getSelected();
				verGrupoContrato(cc);
			}
		});

		refreshLista();

		txtDescricao.focus();
	}

	@SuppressWarnings({ "rawtypes", "unchecked" })
	private void verGrupoContrato(GrupoContrato gc) {
		if (gc == null) {
			return;
		}

		Map args = new HashMap();
		args.put("grupoContrato", gc);
		args.put("grupoContratoList", grupoContratoList);

		openWindow("/gui/configuraciones_comerciales/negcorporativos/editarGrupoContrato.zul",
				Labels.getLabel("editarGrupoContratoController.window.title"), args, MODAL);
	}

	private void refreshLista() {
		HibernateSearchObject<GrupoContrato> configCategoriaBusqueda =new HibernateSearchObject<GrupoContrato>(GrupoContrato.class,pagingGrupoContrato.getPageSize());

		if (txtDescricao.getText().length() > 0) {
			configCategoriaBusqueda.addFilterLike("nomeGrupoContrato", "%" + txtDescricao.getText().trim().concat("%"));
		}
		
		configCategoriaBusqueda.addFilterEqual("activo", Boolean.TRUE);
		configCategoriaBusqueda.addSortAsc("nomeGrupoContrato");

		plwpagingGrupoContrato.init(configCategoriaBusqueda, grupoContratoList, pagingGrupoContrato);

		if (grupoContratoList.getData().length == 0) {
			try {
				Messagebox.show(Labels.getLabel("MSG.ningunRegistro"),
						Labels.getLabel("busquedaGrupoContratoController.window.title"),
						Messagebox.OK, Messagebox.INFORMATION);
			} catch (InterruptedException ex) {
			}
		}
	}

	public void onClick$btnPesquisa(Event ev) {
		refreshLista();
	}

	public void onClick$btnRefresh(Event ev) {
		refreshLista();
	}

	public void onClick$btnNovo(Event ev) {
		verGrupoContrato(new GrupoContrato());
	}
}
